from datetime import datetime
from typing import Optional

from pydantic import BaseModel


class TodoBase(BaseModel):
    """Base schema for Todo."""

    title: str
    description: Optional[str] = None
    completed: bool = False
    category: Optional[str] = None
    due_date: Optional[datetime] = None


class TodoCreate(TodoBase):
    """Schema for creating a Todo."""

    pass


class TodoUpdate(BaseModel):
    """Schema for updating a Todo."""

    title: Optional[str] = None
    description: Optional[str] = None
    completed: Optional[bool] = None
    category: Optional[str] = None
    due_date: Optional[datetime] = None


class TodoResponse(TodoBase):
    """Schema for Todo response."""

    id: int
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True
